<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fil_PH">
<context>
    <name>MEConfig</name>
    <message>
        <location filename="../mainwindow.ui" line="26"/>
        <source>MX User Manager</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="62"/>
        <source>Administration</source>
        <translation>Administration</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="65"/>
        <source>Add a new user</source>
        <translation>Magdagdag ng User o Tagagamit</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="105"/>
        <source>Add User Account</source>
        <translation>Magdagdag ng Kuwenta ng User o Tagagamit </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="132"/>
        <source>Enter password for new user</source>
        <translation>Ipasok ang password sa bagong user o gumagamit</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="141"/>
        <source>password</source>
        <translation>password</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="173"/>
        <source>Reenter password for new user</source>
        <translation>Ipasok ang password para sa bagong user o tagagamit</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="182"/>
        <source>confirm password</source>
        <translation>kumpirmahin ang password</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="198"/>
        <source>Username of new user</source>
        <translation>Pangalan ng bagong user o tagagamit</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="201"/>
        <source>User login name:</source>
        <translation>Pangalan sa login ng user o tagagamit:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="217"/>
        <location filename="../mainwindow.ui" line="466"/>
        <source>Enter username of new user</source>
        <translation>Ipasok ang pangalan ng bagong user o tagagamit</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="223"/>
        <location filename="../mainwindow.ui" line="472"/>
        <source>username</source>
        <translation>pangalan ng user o tagagamit</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="239"/>
        <location filename="../mainwindow.ui" line="258"/>
        <source>Password for new user</source>
        <translation>Password para sa bagong user o tagagamit</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="242"/>
        <source>Confirm user password:</source>
        <translation>Kumpirmahin ang password ng user of gumagamit:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="261"/>
        <source>User password:</source>
        <translation>Password ng User o gumagamit:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="271"/>
        <source>Grant this user administrative rights to the system (sudo)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="290"/>
        <source>Delete User Account</source>
        <translation>Tanggalin ang Kuwenta ng User o Gumagamit</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="333"/>
        <source>Select user</source>
        <translation>Pumili ng user o gumagamit</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="349"/>
        <location filename="../mainwindow.ui" line="1436"/>
        <source>Select user to delete</source>
        <translation>Piliing ang user o gumagamit na tatanggalin</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="358"/>
        <source>User to delete:</source>
        <translation>User o gumagamit na aalisin:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="374"/>
        <source>Also delete the user&apos;s home directory</source>
        <translation>Alisin din ang  home directory ng user o gumagamit</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="377"/>
        <source>Delete user home directory</source>
        <translation>Alisin ang home directory ng user o gumagamit</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="396"/>
        <source>Rename User Account</source>
        <translation>Palitan ang Kuwenta ng User o Gumagamit</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="408"/>
        <location filename="../mainwindow.ui" line="570"/>
        <source>Select user to modify:</source>
        <translation>Piliin ang user o gumagamit na babaguhin:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="450"/>
        <source>New user name:</source>
        <translation>Bagong pangalan ng user o gumagamit:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="491"/>
        <source>Change User Password</source>
        <translation>Palitan ang Password ng User of Gumagamit</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="519"/>
        <source>new password</source>
        <translation>Bagong password</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="535"/>
        <source>Confirm new password:</source>
        <translation>Kumpirmahin ang bagong password:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="554"/>
        <source>confirm new password</source>
        <translation>kumpirmahin ang bagong password</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="586"/>
        <source>New user password:</source>
        <translation>Bagong password ng user o gumagamit:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="620"/>
        <source>Options</source>
        <translation>Mga pagpipilian</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="623"/>
        <source>Repair a user configuration</source>
        <translation>Ayusin ang configuration ng user o gumagamit</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="657"/>
        <location filename="../mainwindow.ui" line="1393"/>
        <source>Modify User Account</source>
        <translation>Baguhin ang kuwenta ng User o Gumagamit</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="669"/>
        <location filename="../mainwindow.ui" line="685"/>
        <source>Select user to repair</source>
        <translation>Piliin ang user o gumagamit na kukumpunihin</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="672"/>
        <location filename="../mainwindow.ui" line="1445"/>
        <source>User to change:</source>
        <translation>User o gumagamit na babaguhin:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="717"/>
        <source>Restore Defaults</source>
        <translation>Ibalik sa Karaniwang Ayos</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="738"/>
        <source>Restore browser configs to MX defaults</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="744"/>
        <source>Mozilla (Iceweasel or Firefox) configs</source>
        <translation>Configs ng Mozilla (Iceweasel o Firefox) </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="747"/>
        <source>Alt+X</source>
        <translation>Alt+X</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="754"/>
        <source>Restore group memberships to MX defaults</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="760"/>
        <source>Group memberships</source>
        <translation>Group memberships</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="763"/>
        <source>Alt+G</source>
        <translation>Alt+G</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="773"/>
        <source>Change Autologin Settings</source>
        <translation>Baguhin ang kalagayan ng autologin</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="779"/>
        <source>Log in automatically</source>
        <translation>Mag log-in ng automatic</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="786"/>
        <source>Require password to log in</source>
        <translation>Mangailangan ng password sa pag-login</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="801"/>
        <source>Copy/Sync</source>
        <translation>Copy/Sync</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="828"/>
        <source>Copy Between Desktops</source>
        <translation>Mag-Copy sa pagitan ng mga desktop</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="855"/>
        <location filename="../mainwindow.ui" line="922"/>
        <source>Select desktop to copy from</source>
        <translation>Pumili ng desktop na pagkokopyahan</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="868"/>
        <source>Select to only copy files</source>
        <translation>Piliin upang kopyahin lang</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="871"/>
        <source>Copy only</source>
        <translation>Kopyahin lang</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="887"/>
        <location filename="../mainwindow.ui" line="900"/>
        <source>Select desktop to copy to</source>
        <translation>Pumili ng desktop na pagkokopyahan</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="909"/>
        <source>Copy to:</source>
        <translation>Kopyahin sa:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="931"/>
        <source>Copy from:</source>
        <translation>Kopyahin mula sa:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="944"/>
        <source>Select to copy and then delete differences</source>
        <translation>Piliin upang kopyahin at alisin ang mga iba</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="947"/>
        <source>Sync</source>
        <translation>Isabay</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="993"/>
        <source>Select to copy/sync Shared</source>
        <translation>Piliin para kopyahin/isabay Shared</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="996"/>
        <source>Shared folder</source>
        <translation>Shared folder</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1009"/>
        <source>Select to copy/sync entire home</source>
        <translation>Piliin upang kopyahin/isabay ang buong home</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1012"/>
        <source>Entire home</source>
        <translation>Kabuuan ng home</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1028"/>
        <source>Select to copy/sync the browser configuration</source>
        <translation>Piliin upang kopyahin/isabay ang configuration ng  browser</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1031"/>
        <source>Mozilla (Firefox or Iceweasel) configs</source>
        <translation>configs ng Mozilla (Firefox o Iceweasel) </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1044"/>
        <source>Select to copy/sync Documents</source>
        <translation>Piliin upang kopyahin/isabay ang Documents</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1047"/>
        <source>Documents folder</source>
        <translation>folder na Documents</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1054"/>
        <source>What to copy/sync:</source>
        <translation>Alin ang kokopyahin/isasabay:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1070"/>
        <source>Progress</source>
        <translation>Progreso</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1100"/>
        <location filename="../mainwindow.ui" line="1116"/>
        <source>Status of the changes</source>
        <translation>Katayuan ng mga pagbabago</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1119"/>
        <source>Status:</source>
        <translation>Katayuan:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1135"/>
        <source>Progress of the changes</source>
        <translation>Progreso ng mga pagbabago</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1172"/>
        <source>Add/Remove Groups</source>
        <translation>Magdadag/Magtanggal ng mga Groups</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1184"/>
        <source>Add Group</source>
        <translation>Magdagdag ng mga Group</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1211"/>
        <source>Enter name of new group</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1217"/>
        <source>groupname</source>
        <translation>pangalannggroup</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1227"/>
        <source>Create a group with GID &gt; 1000</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1230"/>
        <source>Create a user-level group</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1259"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Enter name of new group&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1262"/>
        <source>Group name:</source>
        <translation>Pangalan ng Group:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1281"/>
        <source>Delete Group</source>
        <translation>Tanggalin ang group</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1350"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Select group to delete&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1359"/>
        <source>Select group to delete:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1366"/>
        <source>*Please doublecheck your selections before applying, removing a wrong group can break your system.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1381"/>
        <source>Group Membership</source>
        <translation>Pagkakasapi sa Group </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1455"/>
        <source>Groups user belongs to (change the groups by selecting/deselecting the appropriate boxes):</source>
        <translation>Ang mga Groups ay nauukol sa (baguhin ang mga grupo sa pagpili/pagali ng kahon na naaangkop):</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1478"/>
        <source>*Please doublecheck your selections before applying, assigning wrong group memberships can break your system. If you made a mistake, use restore group membership in Options tab to restore the defaults.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1507"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Select user to change&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1583"/>
        <source>Cancel any changes then quit</source>
        <translation>Huwag tanggapin ang mga binago at lumabas na</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1586"/>
        <source>Close</source>
        <translation>Isara</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1593"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1634"/>
        <source>Display help </source>
        <translation>Maghanap ng tulong</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1637"/>
        <source>Help</source>
        <translation>Tulong</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1644"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1651"/>
        <source>Apply any changes</source>
        <translation>Tanggapin ang alinmang binago</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1654"/>
        <source>Apply</source>
        <translation>Tanggapin</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1661"/>
        <source>Alt+A</source>
        <translation>Alt+A</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1668"/>
        <source>About this application</source>
        <translation>Patungkol sa application na ito</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1671"/>
        <source>About...</source>
        <translation>Patungkol sa...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1678"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="109"/>
        <location filename="../mainwindow.cpp" line="154"/>
        <location filename="../mainwindow.cpp" line="162"/>
        <location filename="../mainwindow.cpp" line="180"/>
        <location filename="../mainwindow.cpp" line="189"/>
        <location filename="../mainwindow.cpp" line="197"/>
        <location filename="../mainwindow.cpp" line="672"/>
        <location filename="../mainwindow.cpp" line="696"/>
        <location filename="../mainwindow.cpp" line="723"/>
        <location filename="../mainwindow.cpp" line="871"/>
        <location filename="../mainwindow.cpp" line="936"/>
        <location filename="../mainwindow.cpp" line="942"/>
        <location filename="../mainwindow.cpp" line="947"/>
        <location filename="../mainwindow.cpp" line="950"/>
        <location filename="../mainwindow.cpp" line="952"/>
        <source>none</source>
        <translation>wala</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="139"/>
        <location filename="../mainwindow.cpp" line="659"/>
        <location filename="../mainwindow.cpp" line="877"/>
        <location filename="../mainwindow.cpp" line="885"/>
        <source>browse...</source>
        <translation>maghanap...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="206"/>
        <source>The user configuration will be repaired. Please close all other applications now. When finished, please logout or reboot. Are you sure you want to repair now?</source>
        <translation>Ang  configuration ng gumagamit ay makukumpuni. Isara ang lahat ng applications ngayon. Sa pagtatapos ay lumabas muna at muling magsimula. Nakakatiyak ka bang gusto mong kumpunihin ngayon?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="227"/>
        <source>User group membership was restored.</source>
        <translation>Ang pagkakasapi ng group ng Gumagamit ay naibalik sa ayos.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="232"/>
        <source>Mozilla settings were reset.</source>
        <translation>Ang settings ng Mozilla ay naibalik muli</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="239"/>
        <location filename="../mainwindow.cpp" line="248"/>
        <source>Autologin options</source>
        <translation>Mga pagpipilian sa kusang pagpasok </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="240"/>
        <source>Autologin has been disabled for the &apos;%1&apos; account.</source>
        <translation>Ang kusang pagpasok ay nakapatay  &apos;%1&apos; kuwente</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="249"/>
        <source>Autologin has been enabled for the &apos;%1&apos; account.</source>
        <translation>Ang kusang pagpasok ay nakasindi para sa kuwenta  &apos;%1&apos;.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="261"/>
        <source>You must specify a &apos;copy to&apos; destination. You cannot copy to the desktop you are logged in to.</source>
        <translation>Dapat mong pangalanan ang &apos;paglalagyang&apos; lugar. Hindi mo maaring kopyahin sa desktop kung saan ka nakapasok.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="268"/>
        <source>Before copying, close all other applications. Be sure the copy to destination is large enough to contain the files you are copying. Copying between desktops may overwrite or delete your files or preferences on the destination desktop. Are you sure you want to proceed?</source>
        <translation>Isara muna ang lahat ngibang applications bago kopyahin. Tiyaking ang kopya</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="292"/>
        <source>Synchronizing desktop...</source>
        <translation>Isinasabay ang desktop...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="294"/>
        <source>Copying desktop...</source>
        <translation>Kinokopya ang desktop...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="322"/>
        <location filename="../mainwindow.cpp" line="533"/>
        <source>The user name needs to be at least 2 characters long. Please select a longer name before proceeding.</source>
        <translation>Ang pangalan ng gumagamit ay dapat 2 characters ang haba. Pumili ng mas mahabang pangalan bago magpatuloy.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="326"/>
        <source>The user name cannot contain special characters or spaces.
Please choose another name before proceeding.</source>
        <translation>Ang pangalan ng gumagamit ay hindi maaring maglamang ng mga espesyal na character maging ng espasyo.
Pumili ng ibang pangalan bago magpatuloy.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="332"/>
        <source>Sorry, this name is in use. Please enter a different name.</source>
        <translation>Paumanhin, ang pangalan na ito ay nagamit na. Magpasok ng ibang pangalan.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="336"/>
        <location filename="../mainwindow.cpp" line="386"/>
        <source>Password entries do not match. Please try again.</source>
        <translation>Ang mga ipinasok na Password ay di magkatugma. Subuking muli.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="342"/>
        <location filename="../mainwindow.cpp" line="392"/>
        <source>Password needs to be at least 2 characters long. Please enter a longer password before proceeding.</source>
        <translation>Ang password ay dapat mahigit sa 2 characters ang biling Magpasok ng mas mahabang password bago magpatuloy.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="375"/>
        <source>The user was added ok.</source>
        <translation>Ang idinagdag na gumagamit maayos.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="378"/>
        <source>Failed to add the user.</source>
        <translation>Bigo sa pagdaragdag ng gumagamit.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="404"/>
        <source>Password successfully changed.</source>
        <translation>Ang Password ay matagumpay na nabago.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="407"/>
        <source>Failed to change password.</source>
        <translation>Bigo sa pagpapalit ng password.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="414"/>
        <source>This action cannot be undone. Are you sure you want to delete user %1?</source>
        <translation>Ang aksyon na ito ay di maaring bawiin. Gusto mo bang tanggalin ang gumagamit %1?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="424"/>
        <source>The user has been deleted.</source>
        <translation>Natanggal na ang gumagamit.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="426"/>
        <source>Failed to delete the user.</source>
        <translation>Bigo sa pagtanggal ng gumagamit.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="439"/>
        <source>The group name needs to be at least 2 characters long. Please select a longer name before proceeding.</source>
        <translation>Ang pangalan ng group ay dapat mahigit sa 2 character. Pumili ng mas mahabang pangalan bago magpatuloy.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="444"/>
        <source>The group name needs to be lower case and it 
cannot contain special characters or spaces.
Please choose another name before proceeding.</source>
        <translation>Ang pangalan ng group ay dapat maliit na titik at hindi dapat maglaman ng espesyal na character. Pumili ng ibang pangalan bago magpatuloy.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="452"/>
        <source>Sorry, that group name already exists. Please enter a different name.</source>
        <translation>Paumanhin. ang pangalan ng group ay umiiral na. Pumili ng ibang pangalan.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="460"/>
        <source>The system group was added ok.</source>
        <translation>Ang grupo para sa sistema ay naidagdag na magatumpay.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="462"/>
        <source>Failed to add the system group.</source>
        <translation>Bigo sa pagdaragdag ng group para sa sistema.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="475"/>
        <source>This action cannot be undone. Are you sure you want to delete group %1?</source>
        <translation>Ang aksyon na ito ay di maaring bawiin. Nakakatiyak ka bang gusto mong tanggalin ang group %1? </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="478"/>
        <source>This action cannot be undone. Are you sure you want to delete the following groups: %1?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="487"/>
        <source>Failed to delete the group.</source>
        <translation>Bigo ang pagtatanggal ng group.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="487"/>
        <source>Group: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="491"/>
        <source>The group has been deleted.</source>
        <translation>Ang group ay natanggal na.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="491"/>
        <source>The groups have been deleted.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="508"/>
        <source>The changes have been applied.</source>
        <translation>Ang mga pagbabago ay natanggap.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="510"/>
        <source>Failed to apply group changes</source>
        <translation>Bigo sa paglalapat ng pagbabago sa group</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="523"/>
        <source>The selected user name is currently in use.</source>
        <translation>Ang pangalan ng user na napili ay kasalukuyang ginagamit.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="524"/>
        <source>To rename this user, please log out and log back in using another user account.</source>
        <translation>Para baguhin ang pangalan ng gumagamit na ito, mangyaring lumabas at pumasok muli gamit ang ibang gumagamit na kuwenta.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="537"/>
        <source>The user name needs to be lower case and it
cannot contain special characters or spaces.
Please choose another name before proceeding.</source>
        <translation>Ang pangalan ng gumagamit ay dapat mga maliit na titik at di maaring maglaman ng mga special character o ng espasyo. Pumili ng ibang pangalan bago magpatuloy.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="544"/>
        <source>Sorry, this name already exists on your system. Please enter a different name.</source>
        <translation>Paumanhin, ang pangalan na ito ay umiiral na sa iyong sistema. Pumili ng ibang pangalan.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="552"/>
        <source>Failed to rename the user. Please make sure that the user is not logged in, you might need to restart</source>
        <translation>Bigo sa pagpapalit ng pangalan ng gumagamit Tiyaking ang  gumagamit ay hindi nakapasok. Maaring mangangailangan kang muling magsimula.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="574"/>
        <source>The user was renamed.</source>
        <translation>Hindi napalitan ang pangalan ng gumagamit.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="586"/>
        <location filename="../mainwindow.cpp" line="613"/>
        <source>Synchronizing desktop...ok</source>
        <translation>Maayos ang pagsasabay ng desktop...ok</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="588"/>
        <location filename="../mainwindow.cpp" line="615"/>
        <source>Copying desktop...ok</source>
        <translation>Kumokopya ng desktop...ok</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="618"/>
        <source>Synchronizing desktop...failed</source>
        <translation>Pagsasabay ng desktop...ay bigo</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="620"/>
        <source>Copying desktop...failed</source>
        <translation>Ang pagkokopya ng desktop...ay bigo</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="637"/>
        <source>Confirmation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="638"/>
        <source>Process not done. Are you sure you want to quit the application?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="843"/>
        <source>About %1</source>
        <translation>Patungkol sa %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="844"/>
        <source>Version: </source>
        <translation>Bersyon: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="845"/>
        <source>Simple user configuration for MX Linux</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="847"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Karapatan (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="848"/>
        <source>%1 License</source>
        <translation>%1 Pahintulot</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="862"/>
        <source>%1 Help</source>
        <translation>%1 Tulong</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="878"/>
        <source>Select folder to copy to</source>
        <translation>Pumili ng folder na kokopyahin</translation>
    </message>
</context>
<context>
    <name>PassEdit</name>
    <message>
        <location filename="../passedit.cpp" line="155"/>
        <source>Negligible</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../passedit.cpp" line="155"/>
        <source>Very weak</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../passedit.cpp" line="155"/>
        <source>Weak</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../passedit.cpp" line="156"/>
        <source>Moderate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../passedit.cpp" line="156"/>
        <source>Strong</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../passedit.cpp" line="156"/>
        <source>Very strong</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../passedit.cpp" line="157"/>
        <source>Password strength: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../passedit.cpp" line="192"/>
        <source>Hide the password</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../passedit.cpp" line="192"/>
        <source>Show the password</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="52"/>
        <source>License</source>
        <translation>Lisensya</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="53"/>
        <location filename="../about.cpp" line="62"/>
        <source>Changelog</source>
        <translation>Ulat na mga pagbabago</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="54"/>
        <source>Cancel</source>
        <translation>Huwag ituloy</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="74"/>
        <source>&amp;Close</source>
        <translation>&amp;Isara</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="58"/>
        <source>Error</source>
        <translation>May error</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="59"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
